import { Route, Routes } from "react-router-dom";
import { Constants, isDevelopmentEnv } from "../../utils";
import { lazy } from "react";
import { MySupsenseFallback } from "../MySupsenseFallback";

// Lazy-loaded components
const Dashboard = lazy(() => import("../../Pages/Dashboard"));
const PageNotFound = lazy(() => import("../../Pages/PageNotFound"));
const PageInDevelopment = lazy(() => import("../../Pages/PageInDevelopment"));
const StoreSettings = lazy(() => import("../../Pages/Store/Settings"));
const StoreEmployees = lazy(() => import("../../Pages/Store/Employees"));
const StoreServices = lazy(() => import("../../Pages/Store/Services"));
const StoreCalendar = lazy(() => import("../../Pages/Store/Calendar"));
const StoreCalendarAuth = lazy(() => import("../../Pages/Store/Calendar/Auth"));
const StoreWebsite = lazy(() => import("../../Pages/Store/Website"));
//const Support = lazy(() => import("../../Pages/Support"));
//const Feedback = lazy(() => import("../../Pages/Feedback"));
const UserProfile = lazy(() => import("../../Pages/UserProfile"));

export default function AppRoutes({ userSession, setUserSession }) {
  //const appContext = useAppContext();

  return (
    <Routes>
      <Route
        path={Constants.ROUTE_PATHS.OVERVIEW}
        element={
          <MySupsenseFallback>
            <Dashboard />
          </MySupsenseFallback>
        }
      />

      <Route
        path={`${Constants.ROUTE_PATHS.STORE.SETTINGS}/:storeId`}
        element={
          <MySupsenseFallback>
            <StoreSettings />
          </MySupsenseFallback>
        }
      />

      <Route
        path={`${Constants.ROUTE_PATHS.STORE.EMPLOYEES}/:storeId`}
        element={
          <MySupsenseFallback>
            <StoreEmployees />
          </MySupsenseFallback>
        }
      />

      <Route
        path={`${Constants.ROUTE_PATHS.STORE.SERVICES}/:storeId`}
        element={
          <MySupsenseFallback>
            <StoreServices />
          </MySupsenseFallback>
        }
      />

      <Route
        path={`${Constants.ROUTE_PATHS.STORE.CALENDAR}/:storeId`}
        element={
          <MySupsenseFallback>
            <StoreCalendar />
          </MySupsenseFallback>
        }
      />

      <Route
        path={`${Constants.ROUTE_PATHS.STORE.CALENDAR_AUTH}/:status`}
        element={
          <MySupsenseFallback>
            <StoreCalendarAuth />
          </MySupsenseFallback>
        }
      />

      <Route
        path={`${Constants.ROUTE_PATHS.STORE.WEBSITE}/:storeId`}
        element={
          <MySupsenseFallback>
            <StoreWebsite />
          </MySupsenseFallback>
        }
      />

      {isDevelopmentEnv() && (
        <>
          <Route
            path={Constants.ROUTE_PATHS.SUPPORT}
            element={
              <MySupsenseFallback>
                <PageInDevelopment />
              </MySupsenseFallback>
            }
          />

          <Route
            path={Constants.ROUTE_PATHS.FEEDBACK}
            element={
              <MySupsenseFallback>
                <PageInDevelopment />
              </MySupsenseFallback>
            }
          />
        </>
      )}

      <Route
        path={Constants.ROUTE_PATHS.USER_PROFILE}
        element={
          <MySupsenseFallback>
            <UserProfile
              userSession={userSession}
              setUserSession={setUserSession}
            />
          </MySupsenseFallback>
        }
      />

      <Route
        path="*"
        element={
          <MySupsenseFallback>
            <PageNotFound />
          </MySupsenseFallback>
        }
      />
    </Routes>
  );
}
