import {
  BellOutlined,
  CheckCircleOutlined,
  CloseCircleOutlined,
  CloseOutlined,
  DeleteOutlined,
  ExclamationCircleOutlined,
  InboxOutlined,
  InfoCircleOutlined,
  MenuFoldOutlined,
  MenuUnfoldOutlined,
  QuestionCircleOutlined,
} from "@ant-design/icons";
import { Badge, Button, Drawer, List, Popconfirm, Typography } from "antd";
import { Header } from "antd/es/layout/layout";
import { useEffect, useState } from "react";
import { useHeaderContext } from "../../Contexts/HeaderContext";
import { myFetch } from "../../utils";
import { useWebSocketContext } from "../../Contexts/WebSocketContext";
import { SentMessagesCommands } from "../../Handlers/WebSocketMessageHandler";
import { useTranslation } from "react-i18next";
import LiveTimeAgo from "../LiveTimeAgo";
import MyPagination from "../MyPagination";

export default function HeaderMenu({
  isSideMenuCollapsed,
  setIsSideMenuCollapsed,
}) {
  //const webSocketContext = useWebSocketContext();
  //const headerContext = useHeaderContext();
  //const { t } = useTranslation();
  const [isNotificationDrawerOpen, setIsNotificationDrawerOpen] =
    useState(false);

  /*
  const fetchNotifications = (page = 1) => {
    myFetch(`/notifications?page=${page}`, "GET").then((data) =>
      headerContext.setNotificationResponse(data)
    );
  };

  const onPaginationChange = (page) => {
    headerContext.setPaginationPage(page);
    headerContext.paginationPageRef.current = page;
  }; */

  /*
  useEffect(() => {
    // fetch will only be called if the drawer is open and there are no notifications
    // further notifications will be fetched by the websocket
    if (!isNotificationDrawerOpen || headerContext.notficationResponse !== null)
      return;

    fetchNotifications(1);
  }, [isNotificationDrawerOpen]);

  useEffect(() => {
    if (!isNotificationDrawerOpen) return;

    fetchNotifications(headerContext.paginationPage);
  }, [headerContext.paginationPage]); */

  return (
    <Header
      style={{
        position: "sticky",
        top: 0,
        zIndex: 10,
        width: "100%",
        display: "flex",
        alignItems: "center",
        padding: 0,
        background: "#fff",
        justifyContent: "space-between",
      }}
    >
      <Button
        type="text"
        icon={
          isSideMenuCollapsed ? <MenuUnfoldOutlined /> : <MenuFoldOutlined />
        }
        onClick={() => setIsSideMenuCollapsed(!isSideMenuCollapsed)}
        style={{ fontSize: "16px", width: 64, height: 64 }}
      />
    </Header>
  );
}

/*
 <Button
        type="text"
        icon={
          <Badge count={headerContext.totalNotifications} offset={[2, -2]}>
            <BellOutlined style={{ fontSize: "16px" }} />
          </Badge>
        }
        onClick={() => setIsNotificationDrawerOpen(true)}
        style={{ fontSize: "16px", width: 64, height: 64 }}
      />

      <Drawer
        title={t("header.notificationDrawer.title")}
        placement="right"
        open={isNotificationDrawerOpen}
        onClose={() => setIsNotificationDrawerOpen(false)}
        extra={
          headerContext.totalNotifications > 0 && (
            <Popconfirm
              title={t("header.notificationDrawer.deleteAllPopconfirm.title")}
              okText={t("common.button.confirm")}
              cancelText={t("common.button.cancel")}
              onConfirm={() => {
                webSocketContext.SendSocketMessage(
                  SentMessagesCommands.DeleteAllNotifications,
                  {}
                );
  
                setIsNotificationDrawerOpen(false); 
              }}
            >
              <Button type="link" icon={<DeleteOutlined />}>
                {t("header.notificationDrawer.deleteAllButtonText")}
              </Button>
            </Popconfirm>
          )
        }
      >
        {isNotificationDrawerOpen && (
          <>
            {headerContext.totalNotifications === 0 ||
            headerContext.notficationResponse === null ? (
              <div style={{ textAlign: "center" }}>
                <InboxOutlined style={{ fontSize: 32, marginBottom: 10 }} />
                <Typography.Title level={5}>
                  {t("header.notificationDrawer.noNotifications")}
                </Typography.Title>
              </div>
            ) : (
              <List
                dataSource={headerContext.notficationResponse.Notifications.sort(
                  (a, b) => {
                    return new Date(b.CreatedAt) - new Date(a.CreatedAt);
                  }
                )}
                footer={
                  <MyPagination
                    paginationPage={headerContext.paginationPage}
                    setPaginationPage={(page) => onPaginationChange(page)}
                    totalPages={headerContext.notficationResponse.TotalPages}
                    size="small"
                  />
                }
                renderItem={(item) => (
                  <List.Item>
                    <List.Item.Meta
                      avatar={<NotificationTypeIcon type={item.Type} />}
                      title={item.Title}
                      description={<LiveTimeAgo startTime={item.CreatedAt} />}
                    />

                    <CloseOutlined
                      onClick={() => {
                        /*webSocketContext.SendSocketMessage(
                          SentMessagesCommands.DeleteOneNotification,
                          {
                            notificationId: item.Id,
                          }
                        )
  
                      }}
                    />
                  </List.Item>
                )}
              />
            )}
          </>
        )}
      </Drawer>
*/

function NotificationTypeIcon({ type }) {
  switch (type) {
    case 1:
      return <CheckCircleOutlined color="#33a834" style={{ fontSize: 16 }} />;
    case 2:
      return <InfoCircleOutlined color="#0c69d7" style={{ fontSize: 16 }} />;
    case 3:
      return (
        <ExclamationCircleOutlined color="#dd9433" style={{ fontSize: 16 }} />
      );
    case 4:
      return <CloseCircleOutlined color="#e5444b" style={{ fontSize: 16 }} />;
    default:
      return <QuestionCircleOutlined color="#fff" style={{ fontSize: 16 }} />;
  }
}
