import { Button, Card, Select, Typography } from "antd";
import { Constants } from "../../utils";
import { useTranslation } from "react-i18next";

export default function UserProfile({ userSession, setUserSession }) {
  const { t, i18n } = useTranslation();

  return (
    <>
      <Card
        title={t("userProfile.title")}
        extra={
          <Button
            type="primary"
            onClick={() => {
              setUserSession();
              window.location.href = "/";

              fetch(`${Constants.API_ADDRESS}/user/auth/logout`, {
                method: "DELETE",
                headers: {
                  "Content-Type": "application/json",
                  "X-Authorization": userSession,
                },
              }).catch(console.error);
            }}
          >
            {t("common.button.logout")}
          </Button>
        }
      >
        <Typography.Paragraph>{t("userProfile.language")}</Typography.Paragraph>

        <Select
          style={{ width: "100%" }}
          defaultValue={i18n.language}
          options={[
            {
              value: "en",
              label: "English",
            },
            {
              value: "de",
              label: "Deutsch",
            },
          ]}
          onChange={(e) => i18n.changeLanguage(e)}
        />
      </Card>
    </>
  );
}
